@@ -403,15 +403,14 @@ sub AUTOLOAD  {
   
   no strict 'refs';
 
-  if ($AUTOLOAD =~ /.*::(\w+)/ &&  $self->_Accessible($1,'read') )  {
+  if ($AUTOLOAD =~ /.*::(\w+)/o &&  $self->_Accessible($1,'read') )  {
     my $Attrib = $1;
 
     *{$AUTOLOAD} = sub { return ($_[0]->_Value($Attrib))};
     return($self->_Value($Attrib));
   }
     
-  elsif ( ($AUTOLOAD =~ /.*::Set(\w+)/ or
-           $AUTOLOAD =~ /.*::set_(\w+)/ ) ) {
+  elsif ($AUTOLOAD =~ /.*::[sS]et_?(\w+)/o) {
 
     if ($self->_Accessible($1,'write')) {
       my $Attrib = $1;
@@ -439,7 +438,7 @@ sub AUTOLOAD  {
   #right idea. it breaks the ability to do ValidateQueue for a ticket
   #on creation.
 
-  elsif ($AUTOLOAD =~ /.*::Validate(\w+)/ ) {
+  elsif ($AUTOLOAD =~ /.*::[vV]alidate_?(\w+)/o ) {
     my $Attrib = $1;
 
     *{$AUTOLOAD} = sub {  return ($_[0]->_Validate($Attrib, $_[1]))};
@@ -967,6 +966,17 @@ sub Create  {
 		delete	$attribs{$key};
 	};
     }
+    unless ($self->_Handle->KnowsBLOBs) {
+        # Support for databases which don't deal with LOBs automatically
+        my $ca = $self->_ClassAccessible();
+        foreach $key (keys %attribs) {
+            if ($ca->{$key}->{'type'} =~ /^(text|longtext|clob|blob|lob)$/i) {
+                my $bhash = $self->_Handle->BLOBParams($key, $ca->{$key}->{'type'});
+                $bhash->{'value'} = $attribs{$key};
+                $attribs{$key} = $bhash;
+            }
+        }
+    }
     return ($self->_Handle->Insert($self->Table, %attribs));
   }
 
